# -*- coding: utf-8 -*-
#
# Copyright (C) 2006-2007 Edgewall Software
# All rights reserved.
#
# This software is licensed as described in the file COPYING, which
# you should have received as part of this distribution. The terms
# are also available at http://posterity.edgewall.org/wiki/License.
#
# This software consists of voluntary contributions made by many
# individuals. For the exact contribution history, see the revision
# history and logs, available at http://posterity.edgewall.org/log/.

from sqlalchemy import create_engine
from elixir import create_all, objectstore, metadata

from posterity.core import PosterityInstance
from posterity.admin import AdminCommand
from posterity.db import init_db, transaction


class InitCommand(AdminCommand):
    """The "init" admin command

    This admin command creates and initializes a new Posterity instance
    directory.
    """
    cmd_name = 'init'
    short_help = 'Initialize posterity instance'
    usage = '%prog init [options]'

    def setup_optparser(self):
        self.parser.add_option('-d', '--database', dest='database',
                               help='Database to connect to', 
                               metavar='DBURI')

    def finalize_options(self):
        if not self.options.database:
            self.parser.error('You need to specify a database with --database=')
        if len(self.args) != 0:
            self.parser.error('Invalid number of arguments')

    def run_command(self, argv):
        self.setup_optparser()
        self.options, self.args = self.parser.parse_args(argv)
        self.finalize_options()
        self._verify_instance()
        instance = PosterityInstance(self.options.instance, create=True)
        instance.config.set('posterity', 'database', self.options.database)
        instance.config.write()
        dburi = instance.config.get('posterity', 'database')
        if dburi == 'test:///fixture':
            init_db()
            return
        engine = create_engine(dburi)
        metadata.connect(engine)
        trans = objectstore.create_transaction()
        transaction._push_object(trans)
        try:
            init_db()
            objectstore.flush()
            transaction.commit()
        finally:
            transaction._pop_object(trans)
