# -*- coding: utf-8 -*-
#
# Copyright (C) 2006-2007 Edgewall Software
# All rights reserved.
#
# This software is licensed as described in the file COPYING, which
# you should have received as part of this distribution. The terms
# are also available at http://posterity.edgewall.org/wiki/License.
#
# This software consists of voluntary contributions made by many
# individuals. For the exact contribution history, see the revision
# history and logs, available at http://posterity.edgewall.org/log/.

from paste.httpserver import server_runner

from posterity.admin import AdminCommand
from posterity.core import make_posterity_app


class ServeCommand(AdminCommand):
    """The 'serve' admin command.
    
    This command implements a simple http server. The main purpose for this
    command is to provide a simple way to quickly get Posterity up and 
    running. This server is not recommmended for production use.
    """
    cmd_name = 'serve'
    short_help = 'A built-in http server'
    usage = '%prog serve [options]'
    run_in_transaction = False

    def setup_optparser(self):
        self.parser.add_option('-H', '--host', dest='host', 
                               metavar='HOST', default='0.0.0.0',
                               help='Host address to bind to')
        self.parser.add_option('-p', '--port', dest='port', default=8080,
                               type='int', help='TCP port to listen on', 
                               metavar='PORT')

    def finalize_options(self):
        if len(self.args) != 0:
            self.parser.error('Invalid number of arguments')

    def run(self):
        app = make_posterity_app({}, instance=self.options.instance)
        server_runner(app, {}, host=self.options.host, port=self.options.port)
