# -*- coding: utf-8 -*-
#
# Copyright (C) 2006-2007 Edgewall Software
# All rights reserved.
#
# This software is licensed as described in the file COPYING, which
# you should have received as part of this distribution. The terms
# are also available at http://posterity.edgewall.org/wiki/License.
#
# This software consists of voluntary contributions made by many
# individuals. For the exact contribution history, see the revision
# history and logs, available at http://posterity.edgewall.org/log/.

import md5
import os
import poplib
import socket

from sqlalchemy import *
from elixir import metadata, objectstore, drop_all
from paste.fixture import TestApp
import pkg_resources

from posterity.admin.admin import run_admin
from posterity.core import make_posterity_app, PosterityInstance
from posterity.db import init_db, transaction
from posterity.model import Account, UserSession
from posterity.util import Config
from posterity.util.mail import encode_header


class PosterityTestApp(TestApp):

    def __init__(self):
        instance_dir = self.setup_instance()
        self.instance = PosterityInstance(instance_dir)
        app = make_posterity_app({}, instance=self.instance)
        super(PosterityTestApp, self).__init__(app)
    
    def login(self, username):
        account = Account.get_by(username=username)
        us = UserSession()
        us.account = account
        self.cookies['posterity-session'] = us.cookie
        objectstore.flush()

    def setup_instance(self):
        dburi = os.environ.get('POSTERITY_TEST_DBURI', 'sqlite://')
        engine = create_engine(dburi)
        metadata.connect(engine)
        objectstore.clear()
        trans = objectstore.create_transaction()
        transaction._push_object(trans)
        instance_dir = os.tempnam()
        run_admin(['posterity-admin', 'init', '-i', instance_dir,
                   '--database', 'test:///fixture'])
        a = Account.create('testuser')
        a.set_password('secretpassword')
        objectstore.flush()
        emails = pkg_resources.resource_listdir('posterity.admin', 'tests/data')
        for email in emails: 
            if not  email.endswith('.eml'):
                continue
            filename = pkg_resources.resource_filename('posterity.admin', 
                                                       'tests/data/' + email)
            run_admin(['posterity-admin', 'inject', '-f', filename, 
                       '-i', instance_dir, 'testuser'])
        
        filename = pkg_resources.resource_filename('posterity.admin', 
                                                   'tests/data/test.mbox')
        run_admin(['posterity-admin', 'inject', '--mbox', '-f', filename, 
                   '--instance', instance_dir, 'testuser'])
        return instance_dir
    
    def teardown_instance(self):
        objectstore.clear()
        transaction.rollback()
        transaction._pop_object()
        drop_all()


class MockPOP3(object):
    """A `poplib.POP3` api-compatible fake POP3 server
    
    This server can be used for for unit and functional testing.
    """
    username = None
    logged_in = False
    msgs = None

    def __init__(self, hostname):
        if not 'fake' in hostname:
            raise socket.error(7, 'No address associated with nodename')
        self.msgs = {'1': 'Subject: POPMSG 1\r\n\r\nFoo',
                     '2': 'Subject: POPMSG 2\r\n\r\nFoo'}

    def user(self, username):
        self.username = username
        return '+OK Password required.'

    def pass_(self, password):
        if (self.username, password) != ('foo', 'bar'):
            raise poplib.error_proto('-ERR Login failed.')
        self.logged_in = True
        return '+OK logged in.'

    def uidl(self):
        assert self.logged_in
        msgs = []
        for msgno, body in self.msgs.items():
            msgs.append('%s %s' % (msgno, md5.md5(body).hexdigest()))
        return 'Response', msgs, '1234'
    
    def retr(self, msgno):
        assert self.logged_in
        return 'Response', self.msgs[msgno].splitlines(), '1234'

    def dele(self, msgno):
        assert self.logged_in
        del self.msgs[msgno]
    
    def quit(self):
        pass
