#!/usr/bin/env python

import os
import sys
from setuptools import setup, find_packages

sys.path.append(os.path.join('doc', 'common'))
try:
    from doctools import build_doc, test_doc
except ImportError:
    build_doc = test_doc = None

setup(
    name='Posterity',
    version='0.6',
    license='BSD',
    description='A web-based email system',
    long_description= \
"""Unlike most open source webmail applications Posterity is not just a web
interface for accessing email messages stored on separate legacy IMAP 
servers. Instead Posterity uses its own database based mail storage""",
    author='Edgewall Software',
    author_email='info@edgewall.org',
    url='http://posterity.edgewall.org/',
    download_url = 'http://posterity.edgewall.org/wiki/Download',
    install_requires = ['Babel >= 0.9.1',
                        # Until a SQLAlchemy 0.4 compatible version is released
                        'Elixir == 0.3.0', 
                        'FormEncode >= 0.7.1',
                        'Genshi >= 0.4.3',
                        'Paste >= 1.4',
                        'PasteDeploy >= 1.3',
                        'selector >= 0.8.7', 
                        'SQLAlchemy >= 0.3.10',
                        'SQLAlchemy <= 0.3.99'],
    tests_require = ['Posterity', 'nose', 'pysqlite'],
    zip_safe = False,
    packages = ['posterity', 'posterity.admin', 'posterity.util', 
                'posterity.web'],
    package_data = {'posterity': ['static/*.*', 'templates/*.*',
                                  'locale/*.*', 'locale/*/LC_MESSAGES/*.*']},
    test_suite = 'nose.collector',
    classifiers = [
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'Intended Audience :: End Users/Desktop',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Communications :: Email',
        'Topic :: Communications :: Email :: Email Clients (MUA)',
        'Topic :: Internet :: WWW/HTTP :: WSGI :: Application'
    ],
    entry_points = """
    [paste.app_factory]
    main = posterity.core:make_posterity_app

    [console_scripts]
    posterity-admin = posterity.admin.admin:main

    [posterity.plugins]
    filter = posterity.filter
    controllers = posterity.controllers
    pop3 = posterity.pop3

    [posterity.admin_commands]
    init = posterity.admin.init:InitCommand
    inject = posterity.admin.inject:InjectCommand
    account = posterity.admin.account:AccountCommand
    serve = posterity.admin.serve:ServeCommand
    fetch = posterity.admin.fetch:FetchCommand
    """,
    cmdclass = {'build_doc': build_doc, 'test_doc': test_doc},
    message_extractors = {
        'posterity': [
            ('**.py',                'python', None),
            ('**/templates/**.html', 'genshi', None),
        ],
    },
)
    
